@@ -11,6 +11,7 @@ import mimetypes
 import os
 import threading
 import pprint
+import json
 
 from Magics import macro
 
@@ -445,7 +446,20 @@ class Styler(datatypes.Styler):
 
     log = logging.getLogger(__name__)
 
+    def __init__(self,  user_style=None):
+        self.user_style = None
+        if user_style:
+            try: 
+                with open(user_style, "r") as f:
+                    self.user_style = json.load(f)
+                    if "name" not in self.user_style:
+                        self.user_style["name"] = "user_style"
+            except:
+                self.user_style = None
+
     def netcdf_styles(self, field, ncvar, path, variable):
+        if self.user_style:
+            return [MagicsWebStyle(self.user_style["name"])]
         with LOCK:
             try:
                 styles = macro.wmsstyles(
@@ -461,6 +475,9 @@ class Styler(datatypes.Styler):
         return [MagicsWebStyle(**s) for s in styles.get("styles", [])]
 
     def grib_styles(self, field, grib, path, index):
+        if self.user_style:
+            return [MagicsWebStyle(self.user_style["name"])]
+
         with LOCK:
             try:
                 styles = macro.wmsstyles(
@@ -476,6 +493,10 @@ class Styler(datatypes.Styler):
         return [MagicsWebStyle(**s) for s in styles.get("styles", [])]
 
     def contours(self, field, driver, style, legend={}):
+
+        if self.user_style:
+            return driver.mcont(self.user_style)
+
         if style is None:
             return driver.mcont()
 
